import"./outputWidgets.dcbaec6c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="68917d3e-1fc9-4032-b754-78987a0786ac",e._sentryDebugIdIdentifier="sentry-dbid-68917d3e-1fc9-4032-b754-78987a0786ac")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.5c03711e.js.map
