import{d as _,eA as w,ez as g,J as D,b as n,eu as b,u,c as d,ew as p,bg as k,x as P}from"./outputWidgets.dcbaec6c.js";import{D as I,m as x}from"./DashPlayer.bb28ea48.js";import{L as B}from"./CircularLoading.e9015f16.js";import{r as R}from"./index.678801af.js";import{B as q}from"./BackButton.d4b3163b.js";import{a as l}from"./asyncComputed.05eefdbd.js";import{D as C}from"./dashes.55e540d6.js";import{W as E}from"./workspaces.afe95fae.js";import"./executeJs.2ae0ce97.js";import"./icons.eaf14b7d.js";import"./index.1b0d4b17.js";import"./pubsub.999268d8.js";import"./PlayerNavbar.29807a52.js";import"./Steps.900c6b2c.js";import"./geometryUtils.df7f9816.js";import"./WidgetsFrame.63b8af8d.js";import"./activeRecord.d9292c93.js";import"./url.5c03711e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="2d59816a-ce0b-44ce-973c-70362bde2802",t._sentryDebugIdIdentifier="sentry-dbid-2d59816a-ce0b-44ce-973c-70362bde2802")}catch{}})();const F=_({__name:"DashPreview",setup(t){const r=w(),s=g(),m=({id:e,type:o})=>{o==="dash"?(s.push({name:"dashPreview",params:{dashId:e},query:r.query}),h()):s.push({name:"formPreview",params:{formId:e},query:r.query})},f=()=>{var e;!((e=a.value)!=null&&e.path)||s.push(`/_editor/dash/${encodeURIComponent(a.value.path)}`)},{loading:v,result:a,refetch:h}=l(()=>C.get(r.params.dashPath)),{result:i}=l(()=>E.get()),c=D(()=>{if(!a.value||!i.value||!a.value.makeRunnerData(i.value))return null;const e=x(a.value.makeRunnerData(i.value));return e.onRedirect(({url:o,queryParams:y})=>R("preview",s,o,y)),e});return(e,o)=>(n(),b(k,null,[u(v)||!u(a)?(n(),d(B,{key:0,class:"loading",justify:"center"})):p("",!0),c.value?(n(),d(I,{key:1,class:"player",dash:c.value.runnerData,"widgets-with-errors":[],"is-preview":!0,params:u(r).query,"dash-player-service":c.value,onNavigate:m},null,8,["dash","params","dash-player-service"])):p("",!0),u(a)?(n(),d(q,{key:2,onExitFullscreenPreview:f})):p("",!0)],64))}});const X=P(F,[["__scopeId","data-v-1172cf43"]]);export{X as default};
//# sourceMappingURL=DashPreview.4e892439.js.map
