import{v as a}from"./icons.eaf14b7d.js";import{d as c,a as r,b as d,eu as i,f as _,u as l,aJ as u,x as f}from"./outputWidgets.dcbaec6c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f1c85543-7438-48dc-8822-ecc9d87e9b7b",e._sentryDebugIdIdentifier="sentry-dbid-f1c85543-7438-48dc-8822-ecc9d87e9b7b")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:l(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const v=f(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.d4b3163b.js.map
