import{x as o,a,b as i,c,g as p,h as d,_,i as u,T as f,j as l,P as b,C as h,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.dcbaec6c.js";import{u as k}from"./index.1b0d4b17.js";import"./pubsub.999268d8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="948fbbe4-38e3-4b2d-8f23-0b30bf5a255a",e._sentryDebugIdIdentifier="sentry-dbid-948fbbe4-38e3-4b2d-8f23-0b30bf5a255a")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.212fdf6d.js"),["assets/Player.212fdf6d.js","assets/index.678801af.js","assets/outputWidgets.dcbaec6c.js","assets/outputWidgets.e6401203.css","assets/uuid.474712e6.js","assets/broker.d63d8af1.js","assets/index.1b0d4b17.js","assets/pubsub.999268d8.js","assets/executeJs.2ae0ce97.js","assets/icons.eaf14b7d.js","assets/CircularLoading.e9015f16.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.29807a52.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.900c6b2c.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.63b8af8d.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.e44f814c.js","assets/broker.1fe265d9.css","assets/DashPlayer.bb28ea48.js","assets/geometryUtils.df7f9816.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.05eefdbd.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(b),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.52ec215e.js.map
