import{x as t,b as s,eu as o}from"./outputWidgets.dcbaec6c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="60b0f504-0fed-4260-a98e-6385e87b112d",e._sentryDebugIdIdentifier="sentry-dbid-60b0f504-0fed-4260-a98e-6385e87b112d")}catch{}})();const r={},d={class:"organization-settings"};function i(e,n){return s(),o("div",d,"Organization settings")}const c=t(r,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.c9ea7cfa.js.map
