import{cG as d}from"./outputWidgets.dcbaec6c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="625041ab-4f2a-4594-bd54-79a9c98d21e7",e._sentryDebugIdIdentifier="sentry-dbid-625041ab-4f2a-4594-bd54-79a9c98d21e7")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.86d2a071.js.map
