import{S as c}from"./Sidebar.ff88e382.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.7fcc10cd.js";import{G as l,H as d,I as u}from"./icons.eaf14b7d.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.dcbaec6c.js";import{a as w}from"./asyncComputed.05eefdbd.js";import"./router.fe36cb8d.js";import{O as z}from"./organization.4e8f2f68.js";import"./index.2b422cbf.js";import{B as h}from"./BaseLayout.7aa9f430.js";import"./Tooltip.1154f5d1.js";import"./logo.084e5d7c.js";import"./index.9fcba2ca.js";import"./Title.137468a8.js";import"./index.a56c5205.js";import"./index.3c7c5d6b.js";import"./index.678801af.js";import"./gateway.f4357ae1.js";import"./activeRecord.d9292c93.js";import"./pubsub.999268d8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b337e728-ce03-49c9-90c9-076fbe217dbe",e._sentryDebugIdIdentifier="sentry-dbid-b337e728-ce03-49c9-90c9-076fbe217dbe")}catch{}})();const q=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:d,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.eeeab3c8.js.map
