import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.dcbaec6c.js";import{S as w,L as j}from"./SmartConsole.02ad3457.js";import{a as x}from"./asyncComputed.05eefdbd.js";import{J as I}from"./jobs.8d7f79b7.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.9935a71b.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.54ee9498.js";import{B as S}from"./BaseLayout.7aa9f430.js";import{_ as T,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.0986d28e.js";import{c as D}from"./index.3c7c5d6b.js";import{A as _,T as R}from"./TabPane.fc42b1c2.js";import"./forms.71227c25.js";import"./activeRecord.d9292c93.js";import"./pubsub.999268d8.js";import"./dashes.55e540d6.js";import"./index.678801af.js";import"./hooks.02c70748.js";import"./workspaces.afe95fae.js";import"./url.5c03711e.js";import"./icons.eaf14b7d.js";import"./Title.137468a8.js";import"./index.12134aed.js";import"./uuid.474712e6.js";import"./ant-design.f602ec67.js";import"./RunButton.vue_vue_type_script_setup_true_lang.7307b493.js";import"./index.b4a5eea4.js";import"./index.69bd7c01.js";import"./dayjs.b4a5fc89.js";import"./Form.94b2db91.js";import"./index.a56c5205.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="8cca502f-415c-49ed-ad4f-8b0bbd79b69f",i._sentryDebugIdIdentifier="sentry-dbid-8cca502f-415c-49ed-ad4f-8b0bbd79b69f")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),c=k(),l=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(c.params.jobId)),f=j.create();return($,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:l,job:e(t),"log-service":e(f)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=l.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.096fa21e.js.map
