import{R as d}from"./Title.137468a8.js";import{F as n}from"./outputWidgets.dcbaec6c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d05df750-66b0-4cf0-af8b-8639a5c65053",e._sentryDebugIdIdentifier="sentry-dbid-d05df750-66b0-4cf0-af8b-8639a5c65053")}catch{}})();const s=n(d);export{s as A};
//# sourceMappingURL=index.12134aed.js.map
