import{d as r,r as c,o as u,eQ as f,b as y,c as p,w as d,f as b,aJ as g,eC as m,eO as w,u as i,c4 as k,eW as _}from"./outputWidgets.dcbaec6c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="91e047ce-b280-4de9-8f10-433459c5c166",e._sentryDebugIdIdentifier="sentry-dbid-91e047ce-b280-4de9-8f10-433459c5c166")}catch{}})();const B=r({__name:"ActionButton",props:{action:{},displayName:{},loading:{type:Boolean}},emits:["click"],setup(e,{emit:n}){const o=e,a=c(null);return u(()=>{a.value&&o.action.setElement(a.value),f.addAction(o.action)}),(s,t)=>(y(),p(i(_),null,{default:d(()=>[b(i(k),{ref_key:"element",ref:a,class:"next-button",loading:s.loading,onClick:t[0]||(t[0]=l=>n("click")),onKeydown:t[1]||(t[1]=w(l=>n("click"),["enter"]))},{default:d(()=>[g(m(s.displayName),1)]),_:1},8,["loading"])]),_:1}))}});export{B as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.e44f814c.js.map
