import{W as a}from"./outputWidgets.dcbaec6c.js";import{c as d,d as c}from"./index.b4a5eea4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="04442b54-4218-482e-933e-78dd48b11462",e._sentryDebugIdIdentifier="sentry-dbid-04442b54-4218-482e-933e-78dd48b11462")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:o,RangePicker:s}=d(c),y=a(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:s,TimePicker:f,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(s.name,s),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,s as R,r as W};
//# sourceMappingURL=dayjs.770f899d.js.map
