import"./outputWidgets.dcbaec6c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="9574b345-727b-4d92-8c20-efcc25bb9f10",e._sentryDebugIdIdentifier="sentry-dbid-9574b345-727b-4d92-8c20-efcc25bb9f10")}catch{}})();function s(e){return e.charAt(0).toUpperCase()+e.slice(1)}function d(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{s as c,d as n};
//# sourceMappingURL=string.59fe6494.js.map
