import{d as u,eA as b,J as f,b as y,c as g,u as _}from"./outputWidgets.dcbaec6c.js";import{a as w}from"./asyncComputed.05eefdbd.js";import"./router.fe36cb8d.js";import{M as n}from"./member.fdc0b2bb.js";import"./index.2b422cbf.js";import{C as I}from"./CrudView.4ac6b440.js";import"./Title.137468a8.js";import"./index.678801af.js";import"./gateway.f4357ae1.js";import"./activeRecord.d9292c93.js";import"./pubsub.999268d8.js";import"./icons.eaf14b7d.js";import"./index.9fcba2ca.js";import"./Form.94b2db91.js";import"./url.5c03711e.js";import"./index.69bd7c01.js";import"./index.12134aed.js";import"./index.87a757a5.js";import"./index.a56c5205.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e106400b-0af3-4a45-b389-d16b29c57a35",e._sentryDebugIdIdentifier="sentry-dbid-e106400b-0af3-4a45-b389-d16b29c57a35")}catch{}})();const F=u({__name:"Members",setup(e){const a=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(a,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(a)),c=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.7b0995d0.js.map
