import"./outputWidgets.dcbaec6c.js";import{M as f}from"./Title.137468a8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e6bae7cf-40ff-4333-9b54-e30dfb9f4969",e._sentryDebugIdIdentifier="sentry-dbid-e6bae7cf-40ff-4333-9b54-e30dfb9f4969")}catch{}})();function r(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:r(n)}));default:return[{title:e,key:e}]}}function s(e){return new Promise(t=>{f.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{s as a,r as t};
//# sourceMappingURL=ant-design.f602ec67.js.map
